==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Test/Gui/Resources/translations/Test_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD Birim Denemesi</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Kusular ve hatalar</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Açıklama</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Başlat</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Yardım</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;Hakkında</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Kapat</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt + C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Beklemede</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>İlerleyiş</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Kalan:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Hatalar:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Arızalar:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Çalıştır:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Denetim</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Denetim için bir ad seçin:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Yardım</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>FreeCAD Birim Denemesi hakkında</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Telif hakkı (c) Werner Mayer'a aittir.

FreeCAD Birim Denetimi bir FreeCAD ürünüdür. Modülleriniz için Birim Denetimi yapmaya olanak tanır.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Çalıştırılabilir bir nesne ismi girerek, DenetimBirimini başlatabilirsiniz. Lütfen önce 'Başlat', a basın, bu şekilde sınama süreci başlatılacaktır.

Lütfen hata ağacı bölümünden varolan bir hata üzerine tıklayarak bu hataya neden olan sorunları da içerecek şekilde bilgi sahibi olun.</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Test/Gui/Resources/translations/Test_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD Birim Denemesi</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Başarısızlıklar ve hatalar</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Açıklama</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Başlat</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Yardım</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;Hakkında</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Kapat</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt + C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Beklemede</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>İlerleyiş</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Kalan:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Hatalar:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Arızalar:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Çalıştır:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Denetim</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Denetim için bir ad seçin:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Yardım</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>FreeCAD Birim Denemesi hakkında</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Telif hakkı (c) Werner Mayer'a aittir.

FreeCAD Birim Denetimi bir FreeCAD ürünüdür. Modülleriniz için Birim Denetimi yapmaya olanak tanır.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Çalıştırılabilir bir nesne ismi girerek, DenetimBirimini başlatabilirsiniz. Lütfen önce 'Başlat', a basın, bu şekilde sınama süreci başlatılacaktır.

Lütfen unsur ağacı bölümünden varolan bir hata üzerine tıklayarak bu hataya neden olan sorunları da içerecek şekilde bilgi sahibi olun.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Çağırılabilir bir nesnenin adını girin; çağırıldığında TestDurumu'na geri gönecektir.
'Başlat'a tıklayın ve böylece oluşturulmuş test başlatılacaktır.

Yığın iz dahil, hata hakkında daha fazla bilgi almak için unsur ağacında hatanın üzerine çift tıklayın.</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Telif hakkı (c) Werner Mayer

FreeCAS BirimTest FreeCAD'in bir parçasıdır ve kişileirn kendi modüllerine test birimleri yazmasını destekler.</translation>
    </message>
  </context>
</TS>
